@@ -106,7 +106,7 @@ def update_documentation(rules):
         new_file.write('| Rule ID  | Title | Description | Source | Tags |\n')
         new_file.write('| -------- | ----- | ----------- | ------ | ---- |\n')
 
-        rule_output = '| {0} <a name="{0}"></a> | {1} | {2} | [Source]({3}) | {4} |\n'
+        rule_output = '| {0}<a name="{0}"></a> | {1} | {2} | [Source]({3}) | {4} |\n'
 
         # Add system Errors (hardcoded)
         parseerror = cfnlint.ParseError()
@@ -124,10 +124,28 @@ def update_documentation(rules):
         new_file.write(
             rule_output.format(ruleerror.id, ruleerror.shortdesc, ruleerror.description, '', tags))
 
+        # Seprate the experimental rules
+        experimental_rules = []
+
         for rule in sorted_rules:
+
+            if rule.experimental:
+                experimental_rules.append(rule)
+                continue
+
             tags = ','.join('`{0}`'.format(tag) for tag in rule.tags)
             new_file.write(rule_output.format(rule.id, rule.shortdesc, rule.description, rule.source_url, tags))
 
+        # Output the experimental rules (if any)
+        if experimental_rules:
+            new_file.write('### Experimental rules\n')
+            new_file.write('| Rule ID  | Title | Description | Source | Tags |\n')
+            new_file.write('| -------- | ----- | ----------- | ------ | ---- |\n')
+
+            for rule in experimental_rules:
+                tags = ','.join('`{0}`'.format(tag) for tag in rule.tags)
+                new_file.write(rule_output.format(rule.id, rule.shortdesc, rule.description, rule.source_url, tags))
+
 def patch_spec(content, region):
     """Patch the spec file"""
     LOGGER.info('Patching spec file for region "%s"', region)
@@ -150,3 +168,26 @@ def patch_spec(content, region):
                     LOGGER.debug('Parent element not found for patch (%s) in region %s', all_patch, region)
 
     return content
+
+def update_iam_policies():
+    """update iam policies file"""
+
+    url = 'https://awspolicygen.s3.amazonaws.com/js/policies.js'
+
+    filename = pkg_resources.resource_filename(
+        __name__,
+        '/data/AdditionalSpecs/Policies.json',
+    )
+    LOGGER.debug('Downloading policies %s into %s', url, filename)
+
+    req = requests.get(url)
+
+    content = req.content.decode('utf-8')
+
+    content = content.split('app.PolicyEditorConfig=')[1]
+    content = json.loads(content)
+    content['serviceMap']['Manage Amazon API Gateway']['Actions'].extend(['HEAD', 'OPTIONS'])
+    content['serviceMap']['Amazon Kinesis Video Streams']['Actions'].append('StartStreamEncryption')
+
+    with open(filename, 'w') as f:
+        json.dump(content, f, indent=2, sort_keys=True, separators=(',', ': '))
